@@ -8,6 +8,8 @@
  */
 
 #include "completionordereditor.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "completionorderwidget.h"
 #include <KLDAPWidgets/LdapClient>
 #include <KLDAPWidgets/LdapClientSearch>
@@ -44,7 +46,7 @@ CompletionOrderEditor::CompletionOrderEditor(KLDAPWidgets::LdapClientSearch *lda
     auto mainLayout = new QVBoxLayout(this);
 
     d->mCompletionOrderWidget = new CompletionOrderWidget(this);
-    d->mCompletionOrderWidget->setObjectName(QLatin1StringView("completionorderwidget"));
+    d->mCompletionOrderWidget->setObjectName("completionorderwidget"_L1);
 
     mainLayout->addWidget(d->mCompletionOrderWidget);
 
@@ -72,14 +74,14 @@ void CompletionOrderEditor::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(600, 400));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myCompletionOrderEditorGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myCompletionOrderEditorGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void CompletionOrderEditor::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myCompletionOrderEditorGroupName));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myCompletionOrderEditorGroupName));
     KWindowConfig::saveWindowSize(windowHandle(), group);
 }
 
